@@ -80,12 +80,11 @@ int main(int argc, char *argv[])
                      QStringLiteral(ALLIGATOR_VERSION_STRING),
                      i18n("Feed Reader"),
                      KAboutLicense::GPL,
-                     i18n("© 2020-2023 KDE Community"));
+                     i18n("© 2020-2024 KDE Community"));
     about.addAuthor(i18n("Tobias Fella"), QString(), QStringLiteral("tobias.fella@kde.org"), QStringLiteral("https://tobiasfella.de"));
     KAboutData::setApplicationData(about);
 
-    AlligatorSettings settings;
-    qmlRegisterSingletonInstance("org.kde.alligator.config", 1, 0, "Config", &settings);
+    qmlRegisterSingletonInstance("org.kde.alligator.config", 1, 0, "AlligatorSettings", AlligatorSettings::self());
 
     QQmlApplicationEngine engine;
     engine.rootContext()->setContextObject(new KLocalizedContext(&engine));
@@ -105,11 +104,11 @@ int main(int argc, char *argv[])
         Database::instance().addFeed(feedURL);
     about.processCommandLine(&parser);
 
-    QObject::connect(&app, &QCoreApplication::aboutToQuit, &settings, &AlligatorSettings::save);
+    QObject::connect(&app, &QCoreApplication::aboutToQuit, AlligatorSettings::self(), &AlligatorSettings::save);
 
     Database::instance();
 
-    engine.load(QUrl(QStringLiteral("qrc:/qml/main.qml")));
+    engine.loadFromModule("org.kde.alligator", "Main");
 
     if (engine.rootObjects().isEmpty()) {
         return -1;
